@@ -1,5 +1,5 @@
 /*
- * "$Id: usersys.c 12813 2015-07-30 15:00:40Z msweet $"
+ * "$Id: usersys.c 12817 2015-07-30 15:45:46Z msweet $"
  *
  * User, system, and password routines for CUPS.
  *
@@ -1012,7 +1012,7 @@ cups_finalize_client_conf(
     struct stat	sockinfo;		/* Domain socket information */
 
     if (!stat(CUPS_DEFAULT_DOMAINSOCKET, &sockinfo) &&
-	(sockinfo.st_mode & S_IRWXO) == S_IRWXO)
+	(sockinfo.st_mode & (S_IROTH | S_IWOTH)) == (S_IROTH | S_IWOTH))
       cups_set_server_name(cc, CUPS_DEFAULT_DOMAINSOCKET);
     else
 #endif /* CUPS_DEFAULT_DOMAINSOCKET */
@@ -1224,10 +1224,10 @@ cups_set_ssl_options(
     const char          *value)		/* I - Value */
 {
  /*
-  * SSLOptions [AllowRC4] [AllowSSL3] [None]
+  * SSLOptions [AllowRC4] [AllowSSL3] [AllowDH] [DenyTLS1.0] [None]
   */
 
-  int	options = 0;			/* SSL/TLS options */
+  int	options = _HTTP_TLS_NONE;	/* SSL/TLS options */
   char	temp[256],			/* Copy of value */
 	*start,				/* Start of option */
 	*end;				/* End of option */
@@ -1256,11 +1256,17 @@ cups_set_ssl_options(
       options |= _HTTP_TLS_ALLOW_RC4;
     else if (!_cups_strcasecmp(start, "AllowSSL3"))
       options |= _HTTP_TLS_ALLOW_SSL3;
+    else if (!_cups_strcasecmp(start, "AllowDH"))
+      options |= _HTTP_TLS_ALLOW_DH;
+    else if (!_cups_strcasecmp(start, "DenyTLS1.0"))
+      options |= _HTTP_TLS_DENY_TLS10;
     else if (!_cups_strcasecmp(start, "None"))
-      options = 0;
+      options = _HTTP_TLS_NONE;
   }
 
   cc->ssl_options = options;
+
+  DEBUG_printf(("4cups_set_ssl_options(cc=%p, value=\"%s\") options=%x", cc, value, options));
 }
 #endif /* HAVE_SSL */
 
@@ -1279,5 +1285,5 @@ cups_set_user(
 
 
 /*
- * End of "$Id: usersys.c 12813 2015-07-30 15:00:40Z msweet $".
+ * End of "$Id: usersys.c 12817 2015-07-30 15:45:46Z msweet $".
  */
