@@ -1,5 +1,5 @@
 /*
- * "$Id: main.c 12701 2015-06-08 18:33:44Z msweet $"
+ * "$Id: main.c 12700 2015-06-08 18:32:35Z msweet $"
  *
  * Main loop for the CUPS scheduler.
  *
@@ -20,6 +20,12 @@
 #define _MAIN_C_
 #include "cupsd.h"
 #include <sys/resource.h>
+#ifdef HAVE_ASL_H
+#  include <asl.h>
+#elif defined(HAVE_SYSTEMD_SD_JOURNAL_H)
+#  define SD_JOURNAL_SUPPRESS_LOCATION
+#  include <systemd/sd-journal.h>
+#endif /* HAVE_ASL_H */
 #include <syslog.h>
 #include <grp.h>
 
@@ -396,6 +402,8 @@ main(int  argc,				/* I - Number of command-line args */
       close(i);
     }
   }
+  else
+    LogStderr = cupsFileStderr();
 
  /*
   * Run in the background as needed...
@@ -728,8 +736,19 @@ main(int  argc,				/* I - Number of command-line args */
 
         if (!cupsdReadConfiguration())
         {
-          syslog(LOG_LPR, "Unable to read configuration file \'%s\' - exiting!",
-		 ConfigurationFile);
+#ifdef HAVE_ASL_H
+	  asl_object_t	m;		/* Log message */
+
+	  m = asl_new(ASL_TYPE_MSG);
+	  asl_set(m, ASL_KEY_FACILITY, "org.cups.cupsd");
+	  asl_log(NULL, m, ASL_LEVEL_ERR, "Unable to read configuration file \"%s\" - exiting.", ConfigurationFile);
+	  asl_release(m);
+#elif defined(HAVE_SYSTEMD_SD_JOURNAL_H)
+	  sd_journal_print(LOG_ERR, "Unable to read configuration file \"%s\" - exiting.", ConfigurationFile);
+#else
+          syslog(LOG_LPR, "Unable to read configuration file \'%s\' - exiting.", ConfigurationFile);
+#endif /* HAVE_ASL_H */
+
           break;
 	}
 
@@ -2120,14 +2139,12 @@ service_checkout(void)
 
 
  /*
-  * Create or remove the systemd path file based on whether there are active
+  * Create or remove the "keep-alive" file based on whether there are active
   * jobs or shared printers to advertise...
   */
 
   if (cupsArrayCount(ActiveJobs) ||	/* Active jobs */
-#  ifdef HAVE_SYSTEMD
       WebInterface ||			/* Web interface enabled */
-#  endif /* HAVE_SYSTEMD */
       (Browsing && BrowseLocalProtocols && cupsArrayCount(Printers)))
 					/* Printers being shared */
   {
@@ -2172,5 +2189,5 @@ usage(int status)			/* O - Exit status */
 
 
 /*
- * End of "$Id: main.c 12701 2015-06-08 18:33:44Z msweet $".
+ * End of "$Id: main.c 12700 2015-06-08 18:32:35Z msweet $".
  */
